@@ -22,14 +22,14 @@ class UWPersonClient(AbstractUWPersonClient):
     def get_person_by_uwnetid(self, uwnetid, **kwargs):
         sqla_person = self.DB.session.query(self.DB.HistoricalPerson).filter(
             self.DB.HistoricalPerson.prior_uwnetid == uwnetid).first()
-        if not sqla_person:
+        if sqla_person is None:
             raise PersonNotFoundException()
         return self._map_person(sqla_person, **kwargs)
 
     def get_person_by_uwregid(self, uwregid, **kwargs):
         sqla_person = self.DB.session.query(self.DB.HistoricalPerson).filter(
             self.DB.HistoricalPerson.prior_uwregid == uwregid).first()
-        if not sqla_person:
+        if sqla_person is None:
             raise PersonNotFoundException()
         return self._map_person(sqla_person, **kwargs)
 
@@ -37,7 +37,7 @@ class UWPersonClient(AbstractUWPersonClient):
         sqla_person = self.DB.session.query(self.DB.Person).join(
             self.DB.Student).filter(
             self.DB.Student.student_number == student_number).one_or_none()
-        if not sqla_person:
+        if sqla_person is None:
             raise PersonNotFoundException()
         return self._map_person(sqla_person, **kwargs)
 
@@ -45,30 +45,34 @@ class UWPersonClient(AbstractUWPersonClient):
         sqla_person = self.DB.session.query(self.DB.Person).join(
             self.DB.Student).filter(
             self.DB.Student.system_key == system_key).one_or_none()
-        if not sqla_person:
+        if sqla_person is None:
             raise PersonNotFoundException()
         return self._map_person(sqla_person, **kwargs)
 
     def get_persons(self, **kwargs):
         sqla_persons = self.DB.session.query(self.DB.Person)
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     def get_registered_students(self, **kwargs):
         sqla_persons = self.DB.session.query(self.DB.Person).join(
             self.DB.Student).filter(
                 self.DB.Student.enroll_status_code == '12'  # registered
         )
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     def get_active_students(self, **kwargs):
         sqla_persons = self.DB.session.query(self.DB.Person).filter(
             self.DB.Person._is_active_student == True)  # noqa
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     def get_active_employees(self, **kwargs):
         sqla_persons = self.DB.session.query(self.DB.Person).filter(
             self.DB.Person._is_active_employee == True)  # noqa
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     def get_advisers(self, advising_program=None, **kwargs):
         sqla_persons = self.DB.session.query(self.DB.Person).join(
@@ -76,7 +80,8 @@ class UWPersonClient(AbstractUWPersonClient):
         if advising_program:
             sqla_persons = sqla_persons.filter(
                 self.DB.Adviser.advising_program == advising_program)
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     def get_persons_by_adviser_netid(self, uwnetid, **kwargs):
         try:
@@ -88,7 +93,8 @@ class UWPersonClient(AbstractUWPersonClient):
         sqla_persons = self.DB.session.query(self.DB.Person).join(
             self.DB.Student).join(self.DB.StudentToAdviser).join(
             self.DB.Adviser).filter(self.DB.Adviser.id == sqla_adviser.id)
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     def get_persons_by_adviser_regid(self, uwregid, **kwargs):
         try:
@@ -100,7 +106,8 @@ class UWPersonClient(AbstractUWPersonClient):
         sqla_persons = self.DB.session.query(self.DB.Person).join(
             self.DB.Student).join(self.DB.StudentToAdviser).join(
             self.DB.Adviser).filter(self.DB.Adviser.id == sqla_adviser.id)
-        return [self._map_person(item, **kwargs)for item in sqla_persons.all()]
+        return [self._map_person(item, **kwargs)
+                for item in sqla_persons.all()]
 
     """
     Private Methods
@@ -114,8 +121,7 @@ class UWPersonClient(AbstractUWPersonClient):
                     include_student_sports=True,
                     include_student_advisers=True,
                     include_student_majors=True,
-                    include_student_pending_majors=True,
-                    include_student_requested_majors=True):
+                    include_student_pending_majors=True):
         person = Person()
         person.uwnetid = sqla_person.uwnetid
         person.uwregid = sqla_person.uwregid
@@ -150,7 +156,6 @@ class UWPersonClient(AbstractUWPersonClient):
                     include_student_advisers=include_student_advisers,
                     include_student_majors=include_student_majors,
                     include_student_pending_majors=include_student_pending_majors,  # noqa
-                    include_student_requested_majors=include_student_requested_majors  # noqa
                 )
             except NoResultFound:
                 pass
@@ -171,8 +176,7 @@ class UWPersonClient(AbstractUWPersonClient):
                      include_student_sports=True,
                      include_student_advisers=True,
                      include_student_majors=True,
-                     include_student_pending_majors=True,
-                     include_student_requested_majors=True):
+                     include_student_pending_majors=True):
         student = Student()
 
         student.system_key = sqla_student.system_key
@@ -325,19 +329,9 @@ class UWPersonClient(AbstractUWPersonClient):
                     self._map_major(sqla_student.pending_major_3))
             student.pending_majors = pending_majors
 
-        if include_student_requested_majors:
-            # map requested majors
-            requested_majors = []
-            if sqla_student.requested_major_1:
-                requested_majors.append(
-                    self._map_major(sqla_student.requested_major_1))
-            if sqla_student.requested_major_2:
-                requested_majors.append(
-                    self._map_major(sqla_student.requested_major_2))
-            if sqla_student.requested_major_3:
-                requested_majors.append(
-                    self._map_major(sqla_student.requested_major_3))
-            student.requested_majors = requested_majors
+        student.requested_major1_code = sqla_student.requested_major1_code
+        student.requested_major2_code = sqla_student.requested_major2_code
+        student.requested_major3_code = sqla_student.requested_major2_code
 
         student.intended_major1_code = sqla_student.intended_major1_code
         student.intended_major2_code = sqla_student.intended_major2_code
